package legion.muyue.best2048;

import android.os.Bundle;
import android.util.TypedValue;
import android.view.Gravity;
import android.widget.TextView;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.content.ContextCompat;
import androidx.gridlayout.widget.GridLayout;

public class MainActivity extends AppCompatActivity {

    private GridLayout gameBoardLayout;
    private TextView scoreTextView;
    private TextView highScoreTextView;
    private Game game;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        gameBoardLayout = findViewById(R.id.gameBoard);
        scoreTextView = findViewById(R.id.scoreLabel);
        highScoreTextView = findViewById(R.id.highScoreLabel);

        game = new Game();

        initGameBoardLayout();

        game.addNewNumbers();
        game.addNewNumbers();
        game.addNewNumbers();
        updateUI();

        // Ajout des listeners de swipe
        setupSwipeListener();
    }
    private void initGameBoardLayout() {
        gameBoardLayout.removeAllViews();
        gameBoardLayout.setColumnCount(4);
        gameBoardLayout.setRowCount(4);
    }

    private void updateUI() {
        gameBoardLayout.removeAllViews(); // Efface les tuiles précédentes

        for (int x = 0; x < 4; x++) {
            for (int y = 0; y < 4; y++) {
                TextView tileTextView = new TextView(this);
                int value = game.getGameBoard(x, y);

                // Choisir le bon drawable en fonction de la valeur
                int drawableId;

                switch (value) {
                    case 2:
                        drawableId = R.drawable.tile2;
                        break;
                    case 4:
                        drawableId = R.drawable.tile4;
                        break;
                    case 8:
                        drawableId = R.drawable.tile8;
                        break;
                    case 16:
                        drawableId = R.drawable.tile16;
                        break;
                    case 32:
                        drawableId = R.drawable.tile32;
                        break;
                    case 64:
                        drawableId = R.drawable.tile64;
                        break;
                    case 128:
                        drawableId = R.drawable.tile128;
                        break;
                    case 256:
                        drawableId = R.drawable.tile256;
                        break;
                    case 512:
                        drawableId = R.drawable.tile512;
                        break;
                    case 1024:
                        drawableId = R.drawable.tile1024;
                        break;
                    case 2048:
                        drawableId = R.drawable.tile2048;
                        break;
                    default:
                        drawableId = R.drawable.tile_empty;
                        break;
                }

                tileTextView.setBackground(ContextCompat.getDrawable(this, drawableId));

                // Afficher le texte uniquement si la valeur est > 0
                if (value > 0) {
                    tileTextView.setText(String.valueOf(value));
                    // Adapte la taille du texte en fonction de la valeur.
                    tileTextView.setTextSize(TypedValue.COMPLEX_UNIT_SP, value < 128 ? 24 : (value < 1024 ? 20 : 16));

                    tileTextView.setTextColor(ContextCompat.getColor(this, R.color.text_tile_low));
                }
                tileTextView.setGravity(Gravity.CENTER);

                GridLayout.LayoutParams params = new GridLayout.LayoutParams();
                params.width = 0;
                params.height = 0;
                params.rowSpec = GridLayout.spec(x, 1f);
                params.columnSpec = GridLayout.spec(y, 1f);
                params.setMargins(10, 10, 10, 10); // Marges codées en dur selon l'extrait
                tileTextView.setLayoutParams(params);

                gameBoardLayout.addView(tileTextView);
            }
        }

        scoreTextView.setText("Score:\n" + game.getScore()); // Concaténation simple selon l'extrait
        highScoreTextView.setText("High Score:\n" + game.getHighScore()); // Concaténation simple selon l'extrait
    }

    private void setupSwipeListener() {
        gameBoardLayout.setOnTouchListener(new OnSwipeTouchListener(MainActivity.this) {
            @Override
            public void onSwipeTop() {
                game.pushUp();
                game.addNewNumbers();
                updateUI();
            }

            @Override
            public void onSwipeBottom() {
                game.pushDown();
                game.addNewNumbers();
                updateUI();
            }

            @Override
            public void onSwipeLeft() {
                game.pushLeft();
                game.addNewNumbers();
                updateUI();
            }

            @Override
            public void onSwipeRight() {
                game.pushRight();
                game.addNewNumbers();
                updateUI();
            }
        });
    }
}